Module client

Module client 

Modules

client_response
Nested message and enum types in ClientResponse.
raft_client_service_client
Generated client implementations.
raft_client_service_server
Generated server implementations.
write_command
Nested message and enum types in WriteCommand.

Structs

ClientReadRequest
ClientResponse
ClientResult
Renamed from ClientGetResult
ClientWriteRequest
KvEntry
A single key-value pair returned by a prefix scan.
MembershipSnapshot
Point-in-time snapshot of committed cluster membership.
ReadResults
ScanRequest
Request to scan all keys under a namespace prefix. Scan is served from the leader’s state machine at last_applied. consistency_policy is not supported; tracked in #381.
ScanResponse
Response from a prefix scan.
WatchMembershipRequest
Request to start a server-side membership watch stream.
WatchRequest
Request to watch for changes on a key or key prefix.
WatchResponse
Response containing a watch event notification
WriteCommand
Write operation-specific command
WriteResult
Write operation result

Enums

ReadConsistencyPolicy
Read consistency policy for controlling read operation guarantees
WatchEventType
Watch event type indicating the type of change that occurred