Modules
- client_
response - Nested message and enum types in
ClientResponse. - raft_
client_ service_ client - Generated client implementations.
- raft_
client_ service_ server - Generated server implementations.
- write_
command - Nested message and enum types in
WriteCommand.
Structs
- Client
Read Request - Client
Response - Client
Result - Renamed from ClientGetResult
- Client
Write Request - KvEntry
- A single key-value pair returned by a prefix scan.
- Membership
Snapshot - Point-in-time snapshot of committed cluster membership.
- Read
Results - Scan
Request - Request to scan all keys under a namespace prefix. Scan is served from the leader’s state machine at last_applied. consistency_policy is not supported; tracked in #381.
- Scan
Response - Response from a prefix scan.
- Watch
Membership Request - Request to start a server-side membership watch stream.
- Watch
Request - Request to watch for changes on a key or key prefix.
- Watch
Response - Response containing a watch event notification
- Write
Command - Write operation-specific command
- Write
Result - Write operation result
Enums
- Read
Consistency Policy - Read consistency policy for controlling read operation guarantees
- Watch
Event Type - Watch event type indicating the type of change that occurred